==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/sql_history/translations/sql_history_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Preparing history database...</source>
        <translation>Préparation de l&apos;historique de la base de données...</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>Opening database failed. Error message:
%1</source>
        <translation>L&apos;ouverture de la base de données a échouée. Message d&apos;erreur :
%1</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
        <translation>Il semble que votre bibliothèque Qt ne prenne pas en charge la base de données sélectionnée. Veuillez installer Qt avec l&apos;extension %1.</translation>
    </message>
</context>
<context>
    <name>SqlInitializer</name>
    <message>
        <source>Copying history file to new location: %1 ...</source>
        <translation>Copie du fichier d&apos;historique vers un nouvel emplacement : %1...</translation>
    </message>
    <message>
        <source>Unable to copy history file to new location. Check if disk is full.</source>
        <translation>Impossible de copier le fichier d&apos;historique vers le nouvel emplacement. Vérifiez si le disque est plein.</translation>
    </message>
    <message>
        <source>Unable to open database: %1</source>
        <translation>Impossible d&apos;ouvrir la base de données : %1</translation>
    </message>
    <message>
        <source>History file is corrupted, performing recovery...</source>
        <translation>Le fichier d&apos;historique est corrompu, récupération en cours...</translation>
    </message>
    <message>
        <source>Recovery completed.</source>
        <translation>Récupération terminée.</translation>
    </message>
    <message>
        <source>Recovery failed: %s</source>
        <translation>La récupération a échoué : %s</translation>
    </message>
    <message>
        <source>History file is outdated, performing import...</source>
        <translation>Le fichier d&apos;historique est périmé, importation en cours...</translation>
    </message>
    <message>
        <source>Import completed.</source>
        <translation>Importation terminée.</translation>
    </message>
    <message>
        <source>Copying completed.</source>
        <translation>Copie terminée.</translation>
    </message>
</context>
<context>
    <name>SqlRestore</name>
    <message>
        <source>No error.</source>
        <translation>Aucune erreur.</translation>
    </message>
    <message>
        <source>sqlite3 executable not found.</source>
        <translation>Le fichier exécutable de sqlite3 est introuvable.</translation>
    </message>
    <message>
        <source>Invalid invocation of recovery script.</source>
        <translation>L&apos;invocation du script de récupération est invalide.</translation>
    </message>
    <message>
        <source>Unable to read corrupted database.</source>
        <translation>Impossible de lire le base de données corrompue.</translation>
    </message>
    <message>
        <source>Unable to create backup file. Disc may be full.</source>
        <translation>Impossible de créer le fichier de sauvegarde. Le disque est certainement plein.</translation>
    </message>
    <message>
        <source>Recovery script not found or not executable.</source>
        <translation>Le script de récupération est introuvable ou n&apos;est pas exécutable.</translation>
    </message>
    <message>
        <source>Unknown error during database recovery.</source>
        <translation>Erreur inconnue durant la récupération de la base</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/sql_history/translations/sql_history_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>HistorySqlStorage</name>
    <message>
        <source>Preparing history database...</source>
        <translation>Préparation de l&apos;historique de la base de données...</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>Opening database failed. Error message:
%1</source>
        <translation>L&apos;ouverture de la base de données a échouée. Message d&apos;erreur :
%1</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>It seems your Qt library does not provide support for selected database. Please install Qt with %1 plugin.</source>
        <translation>Il semble que votre bibliothèque Qt ne prenne pas en charge la base de données sélectionnée. Veuillez installer Qt avec l&apos;extension %1.</translation>
    </message>
</context>
<context>
    <name>SqlInitializer</name>
    <message>
        <source>Copying history file to new location: %1 ...</source>
        <translation>Copie du fichier d&apos;historique vers un nouvel emplacement : %1...</translation>
    </message>
    <message>
        <source>Unable to copy history file to new location. Check if disk is full.</source>
        <translation>Impossible de copier le fichier d&apos;historique vers le nouvel emplacement. Vérifiez si le disque est plein.</translation>
    </message>
    <message>
        <source>Unable to open database: %1</source>
        <translation>Impossible d&apos;ouvrir la base de données : %1</translation>
    </message>
    <message>
        <source>History file is corrupted, performing recovery...</source>
        <translation>Le fichier d&apos;historique est corrompu, récupération en cours...</translation>
    </message>
    <message>
        <source>Recovery completed.</source>
        <translation>Récupération terminée.</translation>
    </message>
    <message>
        <source>Recovery failed: %s</source>
        <translation>La récupération a échoué : %s</translation>
    </message>
    <message>
        <source>History file is outdated, performing import...</source>
        <translation>Le fichier d&apos;historique est périmé, importation en cours...</translation>
    </message>
    <message>
        <source>Import completed.</source>
        <translation>Importation terminée.</translation>
    </message>
    <message>
        <source>Copying completed.</source>
        <translation>Copie terminée.</translation>
    </message>
</context>
<context>
    <name>SqlRestore</name>
    <message>
        <source>No error.</source>
        <translation>Aucune erreur.</translation>
    </message>
    <message>
        <source>sqlite3 executable not found.</source>
        <translation>Le fichier exécutable de sqlite3 est introuvable.</translation>
    </message>
    <message>
        <source>Invalid invocation of recovery script.</source>
        <translation>L&apos;invocation du script de récupération est invalide.</translation>
    </message>
    <message>
        <source>Unable to read corrupted database.</source>
        <translation>Impossible de lire le base de données corrompue.</translation>
    </message>
    <message>
        <source>Unable to create backup file. Disc may be full.</source>
        <translation>Impossible de créer le fichier de sauvegarde. Le disque est certainement plein.</translation>
    </message>
    <message>
        <source>Recovery script not found or not executable.</source>
        <translation>Le script de récupération est introuvable ou n&apos;est pas exécutable.</translation>
    </message>
    <message>
        <source>Unknown error during database recovery.</source>
        <translation>Erreur inconnue durant la récupération de la base</translation>
    </message>
</context>
</TS>
